@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2010-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -43,7 +43,7 @@ from calculate.lib.variables.linux import LinuxDataVars, Linux
 from calculate.lib.cl_vars_share import varsShare
 
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 
@@ -407,7 +407,7 @@ class Distributive(object):
     def performFormat(self):
         pass
 
-    def formatPartition(self,format=""):
+    def formatPartition(self, dev, format="ext4", label=""):
         pass
 
     def rndString(self):
@@ -434,11 +434,12 @@ class Distributive(object):
         """Mount squashfs to directory"""
         NO_SUCH_DEVICE = 2816
         if isMount(directory):
-            raise DistributiveError(_("Failed to mount to the directory: %s\n")\
-                                     %directory+ _("Directory already mounted"))
-        mountopts = filter(lambda x:x,
-                    mountopts.split(" "))
-        mountProcess = process('/bin/mount',file,directory,*mountopts,
+            raise DistributiveError(
+                _("Failed to mount to the directory: %s\n")
+                % directory + _("Directory already mounted"))
+        mountopts_list = filter(lambda x: x,
+                                mountopts.split(" "))
+        mountProcess = process('/bin/mount', file, directory, *mountopts_list,
                                stderr=STDOUT)
         if mountProcess.success():
             return True
@@ -458,13 +459,15 @@ class Distributive(object):
     def _umountDirectory(self,directory):
         """Umount directory"""
         if isMount(directory):
-            for wait in [0,0.5,2,5]:
+            processUmount = None
+            for wait in [0, 0.5, 2, 5]:
                 sleep(wait)
                 processUmount = process('/bin/umount',directory,stderr=STDOUT)
                 if processUmount.success():
                     return True
-            raise DistributiveError(_("Failed to umount") + " %s:\n%s"%
-                                    (directory,processUmount.read()))
+            else:
+                raise DistributiveError(_("Failed to umount") + " %s:\n%s" %
+                                        (directory, processUmount.read()))
         else:
             return True
 
@@ -950,15 +953,17 @@ class PartitionDistributive(Distributive):
                                          self.getMultipartData())
             for dev, mountPoint, fileSystem, isFormat, partTable\
                     in sorted(mulipartDataNotBind, key=lambda x:x[1]):
-                if fileSystem!="swap":
+                realMountPoint = None
+                if fileSystem != "swap":
                     realMountPoint = pathJoin(mdirectory, mountPoint)
-                    self._mountPartition(dev,realMountPoint,"-t %s"%fileSystem)
+                    self._mountPartition(dev, realMountPoint,
+                                         "-t %s" % fileSystem)
                 partObj = PartitionDistributive(dev, flagRemoveDir=False,
                                                 fileSystem=fileSystem,
                                                 isFormat=isFormat,
                                                 parent=dirObj)
-                if fileSystem!="swap":
-                    DirectoryDistributive(realMountPoint,parent=partObj)
+                if realMountPoint is not None:
+                    DirectoryDistributive(realMountPoint, parent=partObj)
         self.DirectoryObject = dirObj
         return dirObj
 
@@ -1014,25 +1019,25 @@ class PartitionDistributive(Distributive):
         if dev in map(lambda y: y.split(" ")[0],
                                 filter(lambda x: x.startswith("/"),
                                         open("/proc/swaps"))):
-            raise DistributiveError(\
-                _("Failed to format %s: this partition is used as swap")%dev)
+            raise DistributiveError(
+                _("Failed to format %s: this partition is used as swap") % dev)
         self._checkMount(dev)
         if not os.access(dev,os.W_OK):
             raise DistributiveError(_("Failed to format the partition") +
                                     " %s:\n%s"%(dev,_("Permission denied")))
         if label:
-            labelStr = self.labelForUtilities.get(format,"")
+            labelStr = self.labelForUtilities.get(format, "")
             if labelStr:
-                labelStr = labelStr%label
+                labelStr = labelStr % label
         else:
             labelStr = ""
-        execStr = self.formatUtilities[format]%(labelStr,dev)
-        res,errmes = self.runOsCommand(execStr)
+        execStr = self.formatUtilities[format] % (labelStr, dev)
+        res, errmes = self.runOsCommand(execStr)
         if res == 0:
             return True
         else:
             raise DistributiveError(_("Failed to format the partition") +
-                                    " %s:\n%s"%(dev,errmes))
+                                    " %s:\n%s" % (dev, errmes))
 
     def performFormat(self):
         """Perform format for all partition of this distributive"""
@@ -1096,7 +1101,7 @@ class PartitionDistributive(Distributive):
         if dev in map(lambda y: y.split(" ")[0],
                                 filter(lambda x: x.startswith("/"),
                                         open("/proc/swaps"))):
-            raise DistributiveError(\
+            raise DistributiveError(
                 _("Failed to execute 'mkswap %s': the swap partition is used "
                   "by the current system") %dev)
         if isMount(dev):
@@ -1296,14 +1301,14 @@ class SquashDistributive(Distributive):
         cmd += ["-progress"]
         if self.exclude:
             cmd += ["-e"] + self.exclude
-        # TODO: отладка
+        # возможность использовать заранее подготовленный livecd.squashfs
         if path.exists('/var/calculate/tmp/livecd.squashfs'):
             os.system('cp /var/calculate/tmp/livecd.squashfs %s' % file)
         else:
             callbackProgress = kwargs.get('callbackProgress', None)
             processMkSquash = PercentProgress(*cmd, stderr=STDOUT, atty=True)
             for perc in processMkSquash.progress():
-                if callbackProgress:
+                if callable(callbackProgress):
                     callbackProgress(perc)
             if processMkSquash.failed():
                 raise DistributiveError(_("Failed to create squashfs") +
@@ -1479,7 +1484,7 @@ class IsoDistributive(Distributive):
         callback_progress = kwargs.get('callbackProgress', None)
         processMkIsoFs = PercentProgress(*cmd, stderr=STDOUT, atty=True)
         for perc in processMkIsoFs.progress():
-            if callback_progress is not None:
+            if callable(callback_progress):
                 callback_progress(perc)
         if processMkIsoFs.failed():
             raise DistributiveError(_("Failed to create the ISO image") +
@@ -1516,9 +1521,9 @@ class IsoDistributive(Distributive):
             # pack iso
             if self.bdirectory != self.file:
                 self.packToIso(isoDirectory, self.file, **kwargs)
-        except DistributiveError,e:
+        except DistributiveError as e:
             raise e
-        except KeyboardInterrupt,e:
+        except KeyboardInterrupt as e:
             raise DistributiveError(_("Keyboard interruption"))
 
     def close(self):
@@ -1548,7 +1553,7 @@ class IsoDistributive(Distributive):
         return ld
 
 class FlashDistributive(PartitionDistributive):
-    def _checkMount(self,dev):
+    def _checkMount(self, dev):
         """Checking mount point"""
         mp = isMount(dev)
         if mp:
@@ -1557,10 +1562,10 @@ class FlashDistributive(PartitionDistributive):
             else:
                 raise DistributiveError(
                     _("Failed to format %s: this partition is mounted")
-                        %dev)
+                    % dev)
 
     def getType(self):
-        return _("USB flash %s")%self.file
+        return _("USB flash %s") % self.partition
 
     def probe(self):
         """Check directory for flash content"""
@@ -1582,156 +1587,9 @@ class FlashDistributive(PartitionDistributive):
                        **kwargs)
         else:
             raise DistributiveError(
-                _("Flash install does not support %s")%
-                    source.__class__.__name__)
+                _("Flash install does not support %s") %
+                source.__class__.__name__)
 
-class ScratchDistributive(Distributive):
-    def __init__(self, directory, parent=None, mdirectory=None, check=False):
-        Distributive.__init__(self, parent=parent)
-        self.directory = directory
-        self.mdirectory = mdirectory or DefaultMountPath.InstallMount
-        if check and not (path.exists(path.join(directory, "workspace")) and
-                          path.exists(path.join(directory, "delta")) and
-                          path.exists(path.join(directory, "calculate"))):
-            raise DistributiveError(
-                _("Wrong scratch distribution in '%s'") % directory)
-
-    def _mountLayers(self,source,target):
-        """Mount squashfs to directory"""
-        self._makeDirectory(target)
-        self._mountToDirectory("none",target,
-            mountopts="-t aufs "+\
-            "-o udba=reval,br:%(work)s=rw:%(delta)s=ro+wh:%(static)s=ro" %\
-                    {"work":path.join(source,"workspace"),
-                     "delta":path.join(source,"delta"),
-                     "static":path.join(source,"calculate")})
-
-    def _umountLayers(self,directory):
-        self._umountDirectory(directory)
-        self._removeDirectory(directory)
-
-    def _mountLiveImage(self,file,directory):
-        """Mount squashfs to directory"""
-        self._makeDirectory(directory)
-        self._mountToDirectory(file,directory,mountopts="-o loop -t squashfs")
-
-    def _umountLiveImage(self,directory):
-        self._umountDirectory(directory)
-
-    def convertToDirectory(self):
-        """Convert scrach directories to one directory"""
-        mdirectory = self.mdirectory
-        for child in self.childs:
-            if isinstance(child,DirectoryDistributive) and \
-                mdirectory in child.directory:
-                return child
-        mdirectory = self._getMntDirectory(mdirectory)
-        liveFile = self._getLastLive(self.directory)
-        self._mountLiveImage(path.join(self.directory,liveFile),
-                path.join(self.directory,"calculate"))
-        self._mountLayers(self.directory,mdirectory)
-        return DirectoryDistributive(mdirectory,parent=self)
-
-    def releaseChild(self,child):
-        """Umount child Directory distributive"""
-        if isinstance(child,DirectoryDistributive):
-            self._umountLayers(child.directory)
-            self._umountLiveImage(path.join(self.directory,"calculate"))
-            child.directory = None
-
-    def installFrom(self, source, **kwargs):
-        """Install distributive to partition from source distributive"""
-        # get source distributive as directory distributive
-        dFrom = source.convertToDirectory()
-        # install into directroy distributive from source
-        self.packToSquash(dFrom.directory, self.file)
-
-class ScratchPartitionDistributive(PartitionDistributive):
-
-    def releaseChild(self,child):
-        """Umount child Directory distributive"""
-        if isinstance(child,DirectoryDistributive):
-            self._umountPartition(child.directory)
-            child.directory = None
-        elif isinstance(child,ScratchDistributive):
-            self._umountPartition(child.directory)
-            child.directory = None
-
-    def convertToDirectory(self):
-        """Convert scratch partition to directory by scratch directory"""
-        return self.convertToScratch().convertToDirectory()
-
-    def convertToScratch(self):
-        mdirectory = self.mdirectory
-        for child in self.childs:
-            if isinstance(child,ScratchDistributive) and \
-                mdirectory in child.directory:
-                return child
-        mdirectory = self._getMntDirectory(mdirectory)
-        self._mountPartition(self.partition,mdirectory)
-
-        return ScratchDistributive(mdirectory,parent=self)
-
-    def prepareScratch(self,directory):
-        """Create need scratch directories"""
-        for scrDirectory in ("calculate","delta","workspace"):
-            self._makeDirectory(path.join(directory,scrDirectory))
-
-    def getBootDirectory(self):
-        """Get directory which contains boot"""
-        return path.join(self.convertToScratch().directory,"boot")
-
-    def getEfiDirectory(self):
-        """Get directory which contains boot"""
-        objDistr =  self.convertToDirectory()
-        mdirectory = objDistr.directory
-        if self.multipartition:
-            mulipartDataNotBind = filter(lambda x: x[2]!="bind",
-                                         self.getMultipartData())
-            for dev, mountPoint, fileSystem, isFormat, partTable\
-                    in mulipartDataNotBind:
-                if mountPoint == '/boot/efi':
-                    realMountPoint = pathJoin(mdirectory, mountPoint)
-                    self._mountPartition(dev,realMountPoint,"-t %s"%fileSystem)
-
-                    partObj = PartitionDistributive(dev, flagRemoveDir=False,
-                                                    fileSystem=fileSystem,
-                                                    isFormat=isFormat,
-                                                    parent=objDistr)
-                    DirectoryDistributive(realMountPoint,parent=partObj)
-        return path.join(mdirectory,"boot/efi")
-
-    def postinstallMountBind(self):
-        pass
-
-    def installFrom(self, source, **kwargs):
-        """Install distributive to partition from source distributive"""
-        # get currect partition as directory
-        distrTo = self.convertToScratch()
-        scratchDirectory = distrTo.directory
-
-        try:
-            # getting squash from source
-            if isinstance(source,IsoDistributive):
-                source = source.convertToSquash()
-            if isinstance(source,SquashDistributive):
-                callbackProgress = kwargs.get('callbackProgress',None)
-                for perc in progressCopyFile(source.file,
-                            path.join(scratchDirectory,"livecd.squashfs")):
-                    if callbackProgress:
-                        callbackProgress(perc)
-            else:
-                distDirectory = source.convertToDirectory()
-                squashDistr = SquashDistributive(
-                               path.join(scratchDirectory,"livecd.squashfs"))
-                squashDistr.installFrom(distDirectory,**kwargs)
-
-            # prepare scratch
-            self.prepareScratch(scratchDirectory)
-        except DistributiveError,e:
-            raise e
-        except KeyboardInterrupt,e:
-            raise DistributiveError(_("Keyboard interruption"))
 
 class PxeDistributive(Distributive):
     needFormat = False
@@ -1744,28 +1602,27 @@ class PxeDistributive(Distributive):
     def getDirectory(self):
         return self.origdir
 
-    def installFrom(self,source, **kwargs):
+    def installFrom(self, source, **kwargs):
         # make temporary directory for creating iso image
         distrTo = self.directory
         # getting squash from source
-        if isinstance(source,IsoDistributive):
+        if isinstance(source, IsoDistributive):
             if path.exists(self.directory):
                 removeDir(self.directory)
             self._makeDirectory(self.directory)
-            self.rsync(source.getIsoContentDirectory(),distrTo,
-                       byfile=lambda x:x.startswith('livecd.'),
+            self.rsync(source.getIsoContentDirectory(), distrTo,
+                       byfile=lambda x: x.startswith('livecd.'),
                        **kwargs)
         else:
             raise DistributiveError(
-                _("PXE install does not support %s"%
-                    source.__class__.__name__))
+                _("PXE install does not support %s" %
+                  source.__class__.__name__))
 
 
 class LayeredDistributive(Distributive):
     """
     Каталог дистрибутива для сборки
     """
-    # TODO: True и удаление данных workdir на форматировании
     needFormat = False
 
     def __init__(self, mdirectory, diff_directory, image_file=None,
@@ -1842,7 +1699,7 @@ class LayeredDistributive(Distributive):
         return DirectoryDistributive(mdirectory, parent=self)
 
     def releaseChild(self, child):
-        """Umount child Directory distributive"""
+        """Unmount child Directory distributive"""
         if isinstance(child,DirectoryDistributive):
             self._umountLayers(child.directory)
             self._umountLiveImage()
