@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -20,17 +20,19 @@ import re
 from os import path
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.lib.utils.files import process, STDOUT, getProgPath, readFile
+from calculate.lib.utils.files import readFile
 from calculate.lib.utils.common import (getVideoFromXorgLog,
-                getVideoFromXorgConf, getVideoFromCmdLine,
-                getAvailableVideo, getValueFromCmdLine,
-                getCompositeFromXorgconf, getVideoFromModules,
-                getVideoFromVendor, getInstalledVideo)
+                                        getVideoFromXorgConf,
+                                        getVideoFromCmdLine,
+                                        getAvailableVideo, getValueFromCmdLine,
+                                        getCompositeFromXorgconf,
+                                        getVideoFromModules,
+                                        getVideoFromVendor, getInstalledVideo)
 from calculate.install.distr import DistributiveError
 import fcntl
 import struct
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 class VideoVariable(Variable):
@@ -64,6 +66,7 @@ class ResolutionVariable(VideoVariable):
     Abstract resolution variable
     """
     fbres = False
+
     def choice(self):
         resolutions = ["640x480", "800x480", "800x600", "1024x576", "1024x600",
                        "1024x768", "1200x800", "1280x800", "1280x720",
@@ -95,7 +98,8 @@ class VariableOsInstallX11Resolution(ResolutionVariable):
     type = 'choiceedit'
     opt = ['-X']
     metavalue = "<width>x<height>"
-    # разрешение пустое, так как xorg.conf использует автодетект на livecd
+    # разрешение по умолчанию пустое - это нужно для livecd
+    # для автоопределения разрешения xorg сервером
     fallback_resolution = ""
 
     def init(self):
