@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -14,16 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os
 import sys
 import re
-from os import path
-from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
-                                   ReadonlyTableVariable, FieldValue)
-from calculate.lib.utils.files import (readFile, getProgPath, process)
+from calculate.lib.datavars import (Variable, ReadonlyVariable,
+                                    ReadonlyTableVariable, FieldValue)
+from calculate.lib.utils.files import readFile
+
+from calculate.lib.cl_lang import setLocalTranslate, _
+
+setLocalTranslate('cl_install3', sys.modules[__name__])
 
-from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_install3',sys.modules[__name__])
 
 class VariableOsAudioData(ReadonlyTableVariable):
     """
@@ -32,9 +32,9 @@ class VariableOsAudioData(ReadonlyTableVariable):
     source = ['os_audio_id',
               'os_audio_name']
 
-    def get(self,hr=False):
+    def get(self, hr=False):
         data = readFile('/proc/asound/cards')
-        cards = re.findall('^\s*(\d+).*\n\s+(\S.*) at .*$',data,re.M)
+        cards = re.findall('^\s*(\d+).*\n\s+(\S.*) at .*$', data, re.M)
         if cards:
             return map(list, cards)
         else:
@@ -65,12 +65,12 @@ class VariableOsAudioDefaultSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
-        res = self.Select('os_audio_id',where='os_audio_name',
-                              notlike='HDMI',limit=1)
-        audioDefault = self.Get('os_audio_default')
-        if audioDefault != '0' or \
-            res and res != "0" and audioDefault == '0' or \
-            audioDefault != self.Get('os_audio_current'):
+        res = self.Select('os_audio_id', where='os_audio_name',
+                          notlike='HDMI', limit=1)
+        audio_default = self.Get('os_audio_default')
+        if (audio_default != '0' or
+                res and res != "0" and audio_default == '0' or
+                audio_default != self.Get('os_audio_current')):
             return 'on'
         return 'off'
 
@@ -80,8 +80,8 @@ class VariableOsAudioCurrent(ReadonlyVariable):
     """
 
     def get(self):
-        defaultCardRe = re.compile('defaults.ctl.card\s+(\d+)')
-        entry = defaultCardRe.search(readFile('/etc/asound.conf'))
+        default_card_re = re.compile('defaults.ctl.card\s+(\d+)')
+        entry = default_card_re.search(readFile('/etc/asound.conf'))
         if entry and entry.groups()[0] in self.Get('os_audio_id'):
             return entry.groups()[0]
         res = self.Select('os_audio_id',where='os_audio_name',
@@ -92,7 +92,7 @@ class VariableOsAudioDefault(Variable):
     """
     Current default audio card
     """
-    type  = "choice"
+    type = "choice"
     opt = ['--audio']
 
     def init(self):
