@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -14,31 +14,26 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os
 import sys
 import re
 from os import path
 from time import sleep
-from calculate.lib.datavars import TableVariable,Variable,VariableError, \
-                                   ReadonlyVariable, ReadonlyTableVariable
-from calculate.lib.utils.device import (getUdevDeviceInfo,getDeviceType,
-                        getPartitionType,getPartitionDevice,getRaidPartitions,
-                        getLvmPartitions,getPartitionSize,getUUIDDict,
-                        humanreadableSize,refreshUdev)
-from calculate.lib.utils.files import (listDirectory,pathJoin,readFile,FStab,
-                                        readLinesFile,process,getProgPath)
-from calculate.install.distr import PartitionDistributive
+from calculate.lib.datavars import (Variable, VariableError,
+                                    VariableInterface,
+                                    ReadonlyVariable, ReadonlyTableVariable)
+from calculate.lib.utils.device import (humanreadableSize,refreshUdev)
+from calculate.lib.utils.files import (readLinesFile,process,getProgPath)
 from calculate.install.fs_manager import FileSystemManager
 from calculate.lib.utils.tools import Sizes
 from itertools import *
 import operator
 
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 
-class SizeHelper:
+class SizeHelper(VariableInterface):
     default_size = Sizes.M
 
     def set(self,value):
@@ -99,8 +94,8 @@ class AutoPartition:
         if table in mapDispatch:
             mapDispatch[table](device,data,bios_grub,bios_grub_size)
         else:
-            raise AutoPartitionError(
-                    _('Autopartitioning for %s is not supported')%table)
+            raise AutopartitionError(
+                _('Autopartitioning for %s is not supported') % table)
 
     def recreatePartitionTableDos(self,device,data,bios_grub,bios_grub_size):
         """
@@ -261,10 +256,12 @@ class AutoPartition:
                                   '--zero-superblock',disk_dev)
         return not failed
 
-    def recreateLvm(self,table,devices,data,vgname,bios_grub,bios_grub_size):
+    def recreateLvm(self, table, devices, data, vgname, bios_grub,
+                    bios_grub_size):
         """
         Create GPT partition table by /sbin/gdisk
         """
+        notInLvm = []
         for i,device in enumerate(devices):
             if i == 0:
                 DEV,MP,FS,SIZE,TABLE=0,1,2,3,4
@@ -291,17 +288,17 @@ class AutoPartition:
                 .format(groupname=vgname,
                         disks=",".join(devices)))
 
-        lvCreateProg = getProgPath('/sbin/lvcreate')
-        for disk,size in map(operator.itemgetter(0,3),
-                         filter(lambda x:not "boot" in x[MP],data)):
+        getProgPath('/sbin/lvcreate')
+        for disk, size in map(operator.itemgetter(0, 3),
+                              filter(lambda x: not "boot" in x[MP], data)):
             lvname = disk.rpartition('/')[2]
-            if not self._createLogicalVolume(vgname,lvname,size):
+            if not self._createLogicalVolume(vgname, lvname, size):
                 raise AutopartitionError(
                     _("Failed to create logical volume {name}")
-                    .format(name=lvname))
+                        .format(name=lvname))
         self._waitDevice('/dev/%s/root'%vgname)
 
-class AutopartitionHelper:
+class AutopartitionHelper(VariableInterface):
     """
     Helper for autopartiton device and mount point creating
     """
@@ -376,7 +373,9 @@ class VariableHrMemorySize(ReadonlyVariable):
     def humanReadable(self):
         return humanreadableSize(self.Get())
 
-class VariableClAutopartitionSwapSize(SizeHelper,AutopartitionHelper,Variable):
+
+class VariableClAutopartitionSwapSize(SizeHelper, AutopartitionHelper,
+                                      Variable):
     """
     Swap size
     """
@@ -398,7 +397,7 @@ class VariableClAutopartitionSwapSize(SizeHelper,AutopartitionHelper,Variable):
     def humanReadable(self):
         return humanreadableSize(int(self.Get()))
 
-class VariableClAutopartitionDevice(AutopartitionHelper,Variable):
+class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
     """
     Device for autopartition
     """
@@ -512,7 +511,9 @@ class VariableClAutopartitionBriefSet(VariableClAutopartitionSet):
             return \
                 _("This option not used for Flash install")
 
-class VariableClAutopartitionScheme(AutopartitionHelper,Variable,AutoPartition):
+
+class VariableClAutopartitionScheme(AutopartitionHelper, AutoPartition,
+                                    Variable):
     """
     Autopartition scheme
     """
@@ -581,7 +582,9 @@ class VariableClAutopartitionRootSizeMin(Variable):
     """
     value = str(Sizes.G*7)
 
-class VariableClAutopartitionRootSize(SizeHelper,AutopartitionHelper,Variable):
+
+class VariableClAutopartitionRootSize(SizeHelper, AutopartitionHelper,
+                                      Variable):
     """
     Root partition size for autopartition
     """
@@ -688,13 +691,13 @@ class VariableClAutopartitionLvmVgname(Variable):
             if set(devices) <= set(self.Get('cl_autopartition_device')):
                 return name
 
-class VariableClAutopartitionDiskDev(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskDev(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition virtual disk on device
     """
     type = "list"
 
-    def generateDisks(self,dos=False,devices=[],scheme=[],number=0):
+    def generateDisks(self, dos=False, devices=(), scheme=(), number=0):
         """
         Generate disks for automount scheme
         """
@@ -702,27 +705,27 @@ class VariableClAutopartitionDiskDev(ReadonlyVariable,AutopartitionHelper):
         for line in self.deviceOpts(scheme):
             # for dos 4 - extension
             # for gpt 4 - for bios_boot
-            if number == 4 and (
-                self.Get('cl_autopartition_bios_grub_set')=='on' or
-                dos):
+            if (number == 4
+                and (self.Get(
+                    'cl_autopartition_bios_grub_set') == 'on' or dos)):
                 number += 1
             yield "%s%d"%(devices[0],number)
             number += 1
 
-    def generateLvm(self,scheme=[],devices=[],**kwargs):
+    def generateLvm(self, scheme=(), devices=(), **kwargs):
         vgname = self.Get('cl_autopartition_lvm_vgname')
         number = 1
-        for line in map(lambda x:{'root':'root2',
-                                  'root2':'root'}.get(x,x),
-                    self.deviceOpts(scheme)):
-            if line in ("boot","uefi"):
-                if number == 4 and \
-                    self.Get('cl_autopartition_bios_grub_set')=='on':
+        for line in map(lambda x: {'root': 'root2',
+                                   'root2': 'root'}.get(x, x),
+                        self.deviceOpts(scheme)):
+            if line in ("boot", "uefi"):
+                if (number == 4 and
+                            self.Get('cl_autopartition_bios_grub_set') == 'on'):
                     number += 1
-                yield "%s%d"%(devices[0],number)
+                yield "%s%d" % (devices[0], number)
                 number += 1
             else:
-                yield "/dev/%s/%s"%(vgname,line)
+                yield "/dev/%s/%s" % (vgname, line)
 
     def diskGenerator(self):
         if self.Get('cl_autopartition_lvm_set') == 'on':
@@ -742,7 +745,7 @@ class VariableClAutopartitionDiskDev(ReadonlyVariable,AutopartitionHelper):
                 return res
         return []
 
-class VariableClAutopartitionDiskScheme(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskScheme(AutopartitionHelper, ReadonlyVariable):
     """
     Назначение раздела относительно схемы авторазметки
     """
@@ -763,7 +766,7 @@ class VariableClAutopartitionDiskScheme(ReadonlyVariable,AutopartitionHelper):
                 return list(self.generateScheme(scheme))
         return []
 
-class VariableClAutopartitionDiskMount(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskMount(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition mount points
     """
@@ -784,7 +787,7 @@ class VariableClAutopartitionDiskMount(ReadonlyVariable,AutopartitionHelper):
                 return list(self.generateMounts(scheme))
         return []
 
-class VariableClAutopartitionDiskFormat(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskFormat(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition disk filesystem
     """
@@ -807,7 +810,7 @@ class VariableClAutopartitionDiskFormat(ReadonlyVariable,AutopartitionHelper):
                 return list(self.generateFormat(scheme))
         return []
 
-class VariableClAutopartitionDiskPart(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskPart(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition partition type (primary,extended,logical,gpt)
     """
@@ -835,7 +838,7 @@ class VariableClAutopartitionDiskPart(ReadonlyVariable,AutopartitionHelper):
                             self.Get('cl_autopartition_table')=='dos'))
         return []
 
-class VariableClAutopartitionDiskType(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskType(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition partition scheme (simple - disk-partition)
     """
@@ -850,7 +853,7 @@ class VariableClAutopartitionDiskType(ReadonlyVariable,AutopartitionHelper):
             return [diskType]*len(self.Get('cl_autopartition_disk_dev'))
         return []
 
-class VariableClAutopartitionDiskSize(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionDiskSize(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition disk size
     """
@@ -949,7 +952,7 @@ class VariableClAutopartitionBindData(ReadonlyTableVariable):
     source = ['cl_autopartition_bind_path',
               'cl_autopartition_bind_mountpoint']
 
-class VariableClAutopartitionBindPath(ReadonlyVariable,AutopartitionHelper):
+class VariableClAutopartitionBindPath(AutopartitionHelper, ReadonlyVariable):
     """
     Autopartition bind points
     """
@@ -966,8 +969,8 @@ class VariableClAutopartitionBindPath(ReadonlyVariable,AutopartitionHelper):
             return list(self.generatePath(scheme))
         return []
 
-class VariableClAutopartitionBindMountpoint(ReadonlyVariable,
-                                            AutopartitionHelper):
+class VariableClAutopartitionBindMountpoint(AutopartitionHelper,
+                                            ReadonlyVariable):
     """
     Autopartition bind points
     """
