@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -17,28 +17,29 @@
 import os
 import sys
 import re
-import pty,fcntl
+import pty, fcntl
 from subprocess import Popen
 from os import path
 from itertools import *
 from operator import itemgetter
-from calculate.lib.datavars import (TableVariable,Variable,VariableError,
-                                    ReadonlyVariable,ReadonlyTableVariable,
-                                    SourceReadonlyVariable)
-from calculate.lib.utils.device import (getUdevDeviceInfo,getDeviceType,
-                        getPartitionType,getPartitionDevice,getRaidPartitions,
-                        getLvmPartitions,getPartitionSize, humanreadableSize,
-                        getUUIDDict,getCommonDeviceName)
+from calculate.lib.datavars import (TableVariable, Variable, VariableError,
+                                    ReadonlyVariable, ReadonlyTableVariable,
+                                    SourceReadonlyVariable, VariableInterface)
+from calculate.lib.utils.device import (getUdevDeviceInfo, getDeviceType,
+                                        getPartitionType, getPartitionDevice,
+                                        getRaidPartitions,
+                                        getLvmPartitions, getPartitionSize,
+                                        humanreadableSize,
+                                        getUUIDDict, getCommonDeviceName)
 from calculate.install.variables.autopartition import Sizes
-from calculate.lib.utils.files import (listDirectory,pathJoin,readFile,FStab,
-                                       isMount,getProgPath)
-from calculate.install.distr import PartitionDistributive
+from calculate.lib.utils.files import (listDirectory, pathJoin, readFile, FStab,
+                                       isMount, getProgPath)
 from calculate.install.fs_manager import FileSystemManager
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
-class DeviceHelper:
+class DeviceHelper(VariableInterface):
     sysBlockPath = '/sys/block'
     rePassDevice = re.compile("^(?!%s)"%"|".join(['sr','fd',
                                                   'ram','loop']))
@@ -101,7 +102,7 @@ class VariableOsDeviceData(ReadonlyTableVariable):
               'os_device_name',
               'os_device_size']
 
-class VariableOsDeviceDev(ReadonlyVariable,DeviceHelper):
+class VariableOsDeviceDev(DeviceHelper,ReadonlyVariable):
     """
     Disk devices
     """
@@ -322,9 +323,9 @@ class VariableOsDeviceName(ReadonlyVariable):
                 devicepath = pathJoin("/sys",devicepath)
             pathVendor = "%s/device/vendor"%devicepath
             pathModel = "%s/device/model"%devicepath
-            return ("%s %s"% \
-                (readFile(pathVendor).strip(),
-                 readFile(pathModel).strip())).strip()
+            return ("%s %s" %
+                    (readFile(pathVendor).strip(),
+                     readFile(pathModel).strip())).strip()
         else:
             return ""
 
@@ -367,7 +368,7 @@ class VariableOsDiskData(ReadonlyTableVariable):
               'os_disk_id',
               'os_disk_grub']
 
-class VariableOsDiskDev(ReadonlyVariable,DeviceHelper):
+class VariableOsDiskDev(DeviceHelper, ReadonlyVariable):
     """
     List of available partition devices
     """
@@ -407,7 +408,7 @@ class VariableOsDiskDev(ReadonlyVariable,DeviceHelper):
         return map(self.getPerfectName,
                self.Get())
 
-class VariableOsDiskMount(ReadonlyVariable,DeviceHelper):
+class VariableOsDiskMount(DeviceHelper, ReadonlyVariable):
     """
     List mounted points for current operation system
     """
@@ -504,7 +505,7 @@ class VariableOsDiskRaid(ReadonlyVariable):
     def get(self):
         return list(self.generateRaid())
 
-class VariableOsDiskLvm(DeviceHelper,ReadonlyVariable):
+class VariableOsDiskLvm(DeviceHelper, ReadonlyVariable):
     """
     LVM vgname and lvname
     """
@@ -514,7 +515,7 @@ class VariableOsDiskLvm(DeviceHelper,ReadonlyVariable):
         return map(self.getLvmName,
                self.Get('os_disk_dev'))
 
-class VariableOsDiskUuid(ReadonlyVariable,DeviceHelper):
+class VariableOsDiskUuid(DeviceHelper, ReadonlyVariable):
     """
     List uudi for partition devices
     """
@@ -536,7 +537,7 @@ class VariableOsDiskParent(ReadonlyVariable):
                map(lambda x:getUdevDeviceInfo(name=x).get('DEVPATH',''),
                self.Get('os_disk_dev')))
 
-class VariableOsDiskId(ReadonlyVariable,DeviceHelper):
+class VariableOsDiskId(DeviceHelper, ReadonlyVariable):
     """
     Partition's system id
     """
@@ -605,7 +606,7 @@ class VariableOsDiskSize(ReadonlyVariable):
         return map(humanreadableSize,
                self.Get())
 
-class VariableOsDiskName(ReadonlyVariable,DeviceHelper):
+class VariableOsDiskName(DeviceHelper, ReadonlyVariable):
     """
     Label of partitions
     """
@@ -663,7 +664,7 @@ class VariableOsBindMountpoint(ReadonlyVariable):
 ######################################################################
 # Userselect partion parameters
 ######################################################################
-class LocationHelper:
+class LocationHelper(VariableInterface):
     """
     Location variable
     """
@@ -939,7 +940,7 @@ class VariableOsLocationDest(LocationHelper,Variable):
                     binds)
         if wrongBind:
             raise VariableError(
-                _("Incorrect mount point (bind '%(bindSrc)s' to "\
+                _("Incorrect mount point (bind '%(bindSrc)s' to "
                               "'%(bindDst)s')")\
                               %{'bindSrc':wrongBind[0][0],
                                 'bindDst':wrongBind[0][1]})
@@ -1153,7 +1154,7 @@ class VariableOsLocationPerformFormat(LocationHelper,Variable):
             # should format if change fs or partition is root, but non flash
             partitionMustFormat = \
                     fixNtfs(diskFormat.get(dev,fs)) != fixNtfs(fs) or \
-                    (mp == '/' and \
+                    (mp == '/' and
                      self.Get('os_install_root_type') != 'flash')
             # if entry has mount point AND
             # partition must was formated
@@ -1317,7 +1318,7 @@ class VariableOsInstallDiskEfi(ReadonlyVariable):
                 func=lambda x:x[0] == 'EF00' and x[1] in validParent)
         return list(set(efiPartitions)-set(self.Get('os_location_source')))
 
-class VariableOsAddonDiskDev(ReadonlyVariable,DeviceHelper):
+class VariableOsAddonDiskDev(DeviceHelper, ReadonlyVariable):
     type = "list"
     def get(self):
         if self.Get('os_install_uefi_set') == 'on':
@@ -1327,7 +1328,7 @@ class VariableOsAddonDiskDev(ReadonlyVariable,DeviceHelper):
                     return efiPartition[:1]
         return []
 
-class VariableOsAddonDiskMount(ReadonlyVariable,DeviceHelper):
+class VariableOsAddonDiskMount(DeviceHelper, ReadonlyVariable):
     type = "list"
     def get(self):
         if self.Get('os_install_uefi_set') == 'on':
@@ -1337,7 +1338,7 @@ class VariableOsAddonDiskMount(ReadonlyVariable,DeviceHelper):
                     return ['/boot/efi']
         return []
 
-class VariableOsAddonDiskFormat(ReadonlyVariable,DeviceHelper):
+class VariableOsAddonDiskFormat(DeviceHelper, ReadonlyVariable):
     type = "list"
     def get(self):
         if self.Get('os_install_uefi_set') == 'on':
@@ -1347,7 +1348,7 @@ class VariableOsAddonDiskFormat(ReadonlyVariable,DeviceHelper):
                     return ['vfat']
         return []
 
-class VariableOsAddonDiskPerformFormat(ReadonlyVariable,DeviceHelper):
+class VariableOsAddonDiskPerformFormat(DeviceHelper, ReadonlyVariable):
     type = "list"
     def get(self):
         if self.Get('os_install_uefi_set') == 'on':
@@ -1362,7 +1363,7 @@ class VariableOsAddonDiskPerformFormat(ReadonlyVariable,DeviceHelper):
                         return ['off']
         return []
 
-class VariableOsInstallDiskDevBase(ReadonlyVariable,DeviceHelper):
+class VariableOsInstallDiskDevBase(DeviceHelper, ReadonlyVariable):
     """
     Variable using for resolv cyclic deps
     """
@@ -1393,7 +1394,7 @@ class VariableOsInstallDiskParentBase(SourceReadonlyVariable):
 
     humanReadable = Variable.humanReadable
 
-class VariableOsInstallDiskDev(ReadonlyVariable,DeviceHelper):
+class VariableOsInstallDiskDev(ReadonlyVariable, DeviceHelper):
     """
     Disks for installation
     """
@@ -1916,7 +1917,7 @@ class VariableOsInstallRootUuid(ReadonlyVariable):
                                where='os_disk_dev',
                                eq=root_dev,limit=1) or ''
 
-class VariableOsInstallFstabMountConf(ReadonlyVariable,DeviceHelper):
+class VariableOsInstallFstabMountConf(DeviceHelper, ReadonlyVariable):
     """
     FStab.conf contains for mount and bind points
     """
