@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -20,18 +20,18 @@ from os import path
 import re
 import operator
 from operator import itemgetter
-from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
-                                CommonVariableError
-from calculate.lib.utils.common import getSupportArch,getTupleVersion, \
-                            cmpVersion
-from calculate.lib.utils.files import readLinesFile, listDirectory
+from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
+                                    CommonVariableError)
+from calculate.lib.utils.common import (getSupportArch, getTupleVersion,
+                                        cmpVersion)
+from calculate.lib.utils.files import listDirectory, pathJoin
 from calculate.lib.variables.linux import Linux
-from calculate.install.distr import (Distributive,PartitionDistributive,
-    DirectoryDistributive,
-    ScratchPartitionDistributive,DistributiveError,FlashDistributive,
-    MultiPartitions,PxeDistributive)
+from calculate.install.distr import (Distributive, PartitionDistributive,
+                                     DirectoryDistributive, DefaultMountPath,
+                                     DistributiveError, FlashDistributive,
+                                     MultiPartitions, PxeDistributive)
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 class DistroRepository(Linux):
@@ -39,15 +39,17 @@ class DistroRepository(Linux):
 
     marches = ['i686','x86_64']
 
-    extensiton = ['iso','tar.bz2','tar.gz','tar.7z','tar.lzma']
+    extensiton = ['iso', 'tar.bz2', 'tar.gz', 'tar.7z', 'tar.lzma']
 
     reDistName = re.compile("""
                 ^.*/(?P<os_linux_shortname>%(name)s)
                 -(?P<os_linux_ver>%(ver)s)
+                (?:-(?P<serial_id>%(ser)s))?
                 -(?P<os_arch_machine>%(march)s)
                 .(?P<ext>%(ext)s)$""" %
                 {'name':"[a-z0-9]+",
                  'ver':r"(\d+\.)*\d+",
+                 'ser':r"\d+",
                  'march':"|".join(marches),
                  'ext':"|".join(extensiton)
                 }, re.X)
@@ -178,15 +180,19 @@ class DistroRepository(Linux):
             return cmpVersion(ver1,ver2)
         build1 = getTupleVersion(x[1].get('os_linux_build',""))
         build2 = getTupleVersion(y[1].get('os_linux_build',""))
-        if  build1 != build2:
+        if build1 != build2:
             return cmp(build1,build2)
         else:
+            ser1, ser2 = (x[1].get('serial_id') or "0",
+                          y[1].get('serial_id') or "0")
+            if ser1 != ser2:
+                return cmp(int(ser1), int(ser2))
             ext1 = x[1].get('ext',"")
             ext2 = y[1].get('ext',"")
             return self.extcomparator(ext1,ext2)
 
     def getAvailableDristibutives(self,dirs,system=None,shortname=None,
-                    march=None, version=None, build=None,discardType=[]):
+                    march=None, version=None, build=None,discardType=()):
         """Get list available distributives"""
         if shortname:
             shortname = shortname.lower()
@@ -200,8 +206,8 @@ class DistroRepository(Linux):
         return map(lambda x:x[0],
                sorted(availDistrs,self.sortdistrfunc,reverse=True))
 
-    def getBestDistributive(self,dirs,system=None,shortname=None,march=None,
-                            version=None, build=None,discardType=[]):
+    def getBestDistributive(self, dirs, system=None, shortname=None, march=None,
+                            version=None, build=None, discardType=()):
         """Get the actualest distributive"""
         availDistrs = self.getAvailableDristibutives(dirs,system,shortname,
                             march,version,build,discardType)
@@ -249,7 +255,8 @@ class VariableClImage(ReadonlyVariable):
     def get(self):
         """Get image file from distributive repository"""
         try:
-            if not self.Get('cl_action') in ('system','prepare'):
+            action = self.Get('cl_action')
+            if not action in ('system',):
                 return Distributive.fromFile('/')
             filename = self.Get('cl_image_filename')
             if filename:
@@ -264,7 +271,7 @@ class VariableClImage(ReadonlyVariable):
             return filename.getType()
         return filename
 
-class VariableClImageFilename(Variable,DistroRepository):
+class VariableClImageFilename(DistroRepository, Variable):
     """
     Distributive image filename
     """
@@ -272,6 +279,7 @@ class VariableClImageFilename(Variable,DistroRepository):
     element = 'file'
     metavalue = "IMAGE"
     opt = ['--iso']
+    check_after = ["os_install_root_type"]
     untrusted = True
 
     def init(self):
@@ -296,9 +304,9 @@ class VariableClImageFilename(Variable,DistroRepository):
         if self.Get('cl_action') == 'system' and not isoimage:
             raise VariableError(_("You need to select a distribution image"))
         imageData = Distributive().getInfo(isoimage)
-        if not("os_linux_shortname" in imageData and \
-               imageData.get('os_linux_build','') and \
-            "os_arch_machine" in imageData):
+        if not ("os_linux_shortname" in imageData and
+                    imageData.get('os_linux_build', '') and
+                        "os_arch_machine" in imageData):
             raise VariableError(_("Wrong image file"))
 
     def humanImageName(self,distroinfo,filepath):
@@ -350,11 +358,12 @@ class VariableClImageFilename(Variable,DistroRepository):
                                         discardType=discardType)
         if self.wasSet and not self.value in distros:
             distros.append(self.value)
-        return sorted(map(lambda x:(x,
-                          self.humanImageName(self._getDistrInfo(x),x)),
-               distros),key=itemgetter(1))
+        return sorted(map(lambda x: (
+            x, self.humanImageName(self._getDistrInfo(x), x)), distros),
+            key=itemgetter(1))
 
-class VariableClImageArchMachine(Variable,DistroRepository):
+
+class VariableClImageArchMachine(DistroRepository, Variable):
     """
     Filter by architecture
     """
@@ -381,7 +390,7 @@ class VariableClImageArchMachine(Variable,DistroRepository):
     def humanReadable(self):
         return self.Get() or _("Not used")
 
-class VariableClImageLinuxShortname(Variable,Linux,DistroRepository):
+class VariableClImageLinuxShortname(DistroRepository, Variable):
     """
     Filter by shortname
     """
@@ -403,7 +412,7 @@ class VariableClImageLinuxShortname(Variable,Linux,DistroRepository):
     def humanReadable(self):
         return self.Get() or _("Not used")
 
-class VariableClImageLinuxVer(Variable,DistroRepository):
+class VariableClImageLinuxVer(DistroRepository, Variable):
     """
     Filter by version
     """
@@ -416,7 +425,7 @@ class VariableClImageLinuxVer(Variable,DistroRepository):
     def humanReadable(self):
         return self.Get() or _("Not used")
 
-class VariableClImageLinuxBuild(Variable,DistroRepository):
+class VariableClImageLinuxBuild(DistroRepository, Variable):
     """
     Filter by build
     """
@@ -448,9 +457,14 @@ class VariableClImagePath(ReadonlyVariable):
                 livedistr = ['/mnt/livecd']
             # standard livecd
             else:
-                livedistr = ['/run/initramfs/squashfs',
-                             '/run/initramfs/live',
-                             '/mnt/cdrom']
+                if self.Get('os_install_root_type') == "flash":
+                    livedistr = ['/run/initramfs/live',
+                                 '/run/initramfs/squashfs',
+                                 '/mnt/cdrom']
+                else:
+                    livedistr = ['/run/initramfs/squashfs',
+                                 '/run/initramfs/live',
+                                 '/mnt/cdrom']
                 livedistr = filter(listDirectory,
                             livedistr)[:1]
         else:
@@ -467,6 +481,7 @@ class VariableClImagePath(ReadonlyVariable):
                ['/var/calculate/remote/linux',
                 '/var/calculate/linux'] + livedistr)
 
+
 class VariableClSource(ReadonlyVariable):
     """
     Дистрибутив текущей системы
@@ -499,28 +514,26 @@ class VariableClTarget(ReadonlyVariable):
         if not systemId or mapDevId.get(disk,'') == systemId:
             systemId = None
         if osInstallScratch:
-            target = ScratchPartitionDistributive(disk,mdirectory='/mnt/install',
-                                    check=True,fileSystem=fileSystem,
-                                    isFormat=self.isTrue(isFormat),
-                                    systemId=systemId,
-                                    partitionTable=partTable)
-        elif self.Get('os_install_pxe') == "on":
+            raise VariableError("Scratch is not supported")
+        if self.Get('os_install_pxe') == "on":
             return PxeDistributive(self.Get('os_install_pxe_path'))
         elif self.Get('os_install_root_type')=="flash":
             flashLabel = "{short}-{build}".format(
                 short="CL", build=self.Get('os_install_linux_build'))
-            return FlashDistributive(disk,mdirectory="/mnt/install",
-                                    check=True, fileSystem=fileSystem,
-                                    isFormat=isFormat, systemId=systemId,
-                                    rootLabel=flashLabel,
-                                    partitionTable=partTable)
+            return FlashDistributive(
+                disk, mdirectory=DefaultMountPath.InstallMount,
+                check=True, fileSystem=fileSystem,
+                isFormat=isFormat, systemId=systemId,
+                rootLabel=flashLabel,
+                partitionTable=partTable)
         else:
-            target = PartitionDistributive(disk,mdirectory='/mnt/install',
-                                    check=True,fileSystem=fileSystem,
-                                    rootLabel=rootLabel,
-                                    isFormat=self.isTrue(isFormat),
-                                    systemId=systemId,
-                                    partitionTable=partTable)
+            target = PartitionDistributive(
+                disk, mdirectory=DefaultMountPath.InstallMount,
+                check=True, fileSystem=fileSystem,
+                rootLabel=rootLabel,
+                isFormat=self.isTrue(isFormat),
+                systemId=systemId,
+                partitionTable=partTable)
         multiPartition = None
         diskData = self.Select(listVars,
                                where='os_install_disk_mount',
@@ -567,7 +580,6 @@ class VariableClImageNewOnly(Variable):
         Get build already installed system
         Need for check update
         """
-        imageData = None
         rootDev = self.Get('os_install_root_dev')
         if not rootDev:
             return ""
@@ -588,3 +600,13 @@ class VariableClImageNewOnly(Variable):
                 self.Get('os_linux_build') or \
                 imageData.get('os_linux_build','') <= self.installedBuild():
                 raise CommonVariableError(_("The image for update not found"))
+
+
+class VariableClInstallPathFrom(ReadonlyVariable):
+    """
+    Путь из устанавливаемой системы до устанавливающий системы
+    """
+    def get(self):
+        template_path = pathJoin(self.Get('cl_chroot_path'),
+                                 self.Get('cl_root_path'))
+        return os.path.relpath("/", template_path)
