@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -14,7 +14,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os
 import sys
 from os import path
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
@@ -25,7 +24,7 @@ from pytz import timezone,country_timezones,UnknownTimeZoneError
 from datetime import datetime
 from operator import itemgetter
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 class LocaleVariable(ReadonlyVariable,Locale):
@@ -60,7 +59,7 @@ class VariableOsInstallLinguas(LocaleVariable):
             return emerge_config['LINGUAS'].encode('UTF-8')
 
         infocommand = ['emerge','--info']
-        defaultLinguas = "bg en de es fr it pl pt_BR ru uk"
+        defaultLinguas = "bg en de es fr it pl pt_BR nl ru uk"
         # get linguas from make.conf, emerge --info or default
         curlanguage = self.Get('os_install_locale_language')
         return get_linguas(readLinesFile(makeconf)) or \
