@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -14,31 +14,29 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import os
 import sys
 import re
 from os import path,readlink
-from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
-    READONLY, TableVariable,FieldValue
+from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
+                                    READONLY, TableVariable, FieldValue,
+                                    VariableInterface)
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
-from calculate.lib.utils.ip import (getInterfaces,getIp,getMask,getMac,
-    cidrToMask,maskToCidr,getIpNet,isDhcpIp,checkIp,checkMask,
-    getOperState,getPlugged)
+from calculate.lib.utils.ip import (getInterfaces, getIp, getMask, getMac,
+                                    cidrToMask, maskToCidr, getIpNet, isDhcpIp,
+                                    checkIp, checkMask,
+                                    getOperState, getPlugged)
 from calculate.lib.utils.device import lspci
-from calculate.lib.utils.files import listDirectory,readLinesFile,process,\
-                                      readFile
+from calculate.lib.utils.files import (listDirectory, readLinesFile)
 from calculate.lib.utils import ip
 from calculate.lib.utils.portage import isPkgInstalled
 from operator import itemgetter
 from itertools import *
-from functools import partial
-import hashlib
 from calculate.install.distr import DistributiveError
 
-class NetHelper:
+class NetHelper(VariableInterface):
     """
     Network variables not using for flash installation
     """
@@ -179,7 +177,6 @@ class VariableOsInstallNetFqdn(NetHelper,Variable):
                 _("The hostname length should be less than %d")%maxfqdn)
 
     def get(self):
-        # TODO: temporary code for quick run on PXE loading
         if path.exists('/proc/self/fd/1') and \
             readlink('/proc/self/fd/1') == '/dev/console' and \
             self.Get('os_root_dev') == '/dev/nfs':
@@ -450,7 +447,8 @@ class VariableOsInstallNetRouteData(NetHelper,TableVariable):
         if not force:
             self._check()
 
-class VariableOsInstallNetRouteNetwork(FieldValue,NetHelper,Variable):
+
+class VariableOsInstallNetRouteNetwork(NetHelper, FieldValue, Variable):
     """
     Net for route table record
     """
@@ -478,7 +476,7 @@ class VariableOsInstallNetRouteNetwork(FieldValue,NetHelper,Variable):
             raise VariableError(
                 _("Network '%s' is used more than once")%dupNetwork[0])
 
-class VariableOsInstallNetRouteGw(FieldValue,NetHelper,Variable):
+class VariableOsInstallNetRouteGw(NetHelper,FieldValue,Variable):
     """
     Gateway for route table record
     """
@@ -511,7 +509,7 @@ class VariableOsInstallNetRouteGw(FieldValue,NetHelper,Variable):
             raise VariableError(_("Gateways %s are unreachable")%
                                  (",".join(wrongGws)))
 
-class VariableOsInstallNetRouteDev(FieldValue,NetHelper,Variable):
+class VariableOsInstallNetRouteDev(NetHelper,FieldValue,Variable):
     """
     Device for route table record
     """
@@ -525,7 +523,7 @@ class VariableOsInstallNetRouteDev(FieldValue,NetHelper,Variable):
     def choice(self):
         return self.Get('os_install_net_interfaces')
 
-class VariableOsInstallNetRouteSrc(FieldValue,NetHelper,Variable):
+class VariableOsInstallNetRouteSrc(NetHelper, FieldValue, Variable):
     """
     Source ip for route table record
     """
@@ -551,7 +549,8 @@ class VariableOsInstallNetRouteSrc(FieldValue,NetHelper,Variable):
                 _("Wrong IP address %s in the specified source IP")%
                                  (",".join(wrongIps)))
 
-class VariableOsInstallNetRoute(NetHelper,ReadonlyVariable):
+
+class VariableOsInstallNetRoute(NetHelper, ReadonlyVariable):
     """
     Data by route for conf.d/net
     """
@@ -579,19 +578,21 @@ class VariableOsInstallNetRoute(NetHelper,ReadonlyVariable):
                       _notin="off")
         if len(workIfaces) == 1:
             defaultDev = workIfaces[0]
-        def getRouteForInterfaceConf(interface,net,routeMatrix):
-            NET,GW,DEV,SRC = 0,1,2,3
+
+        def getRouteForInterfaceConf(interface, net, routeMatrix):
+            NET, GW, DEV, SRC = 0, 1, 2, 3
             return "\n".join(
-               # build string for route from net,gateway,dev and src
-               map(lambda x:"{net}{gateway}{src}".format(
-                   net=x[NET],
-                   gateway=" via %s"%x[GW] if x[GW] else "",
-                   src=" src %s"%x[SRC] if x[SRC] else ""),
-               # filter by interface and discard direct routes
-               # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
-               filter(lambda x:(interface==x[DEV] or defaultDev and \
-                                interface==defaultDev) \
-                      and net!=x[NET],routeMatrix)))
+                # build string for route from net,gateway,dev and src
+                map(lambda x: "{net}{gateway}{src}".format(
+                    net=x[NET],
+                    gateway=" via %s" % x[GW] if x[GW] else "",
+                    src=" src %s" % x[SRC] if x[SRC] else ""),
+                    # filter by interface and discard direct routes
+                    # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
+                    filter(lambda x: (interface == x[DEV] or defaultDev and
+                                      interface == defaultDev) \
+                                     and net != x[NET], routeMatrix)))
+
         return self.performRouteData(getRouteForInterfaceConf)
 
 
@@ -626,12 +627,13 @@ class VariableOsInstallNetNmroute(VariableOsInstallNetRoute):
                # filter by interface and discard direct routes
                # example: for 192.168.1.5/24 discard 192.168.1.0/24 net
                enumerate(
-               filter(lambda x:(interface==x[DEV] or defaultDev and \
+               filter(lambda x:(interface==x[DEV] or defaultDev and
                                 interface==defaultDev) and net!=x[NET] and \
                                x[NET]!="default",routeMatrix))))
         return self.performRouteData(getRouteForInterfaceNM)
 
-class VariableOsInstallNetConfAvailable(NetHelper,Variable):
+
+class VariableOsInstallNetConfAvailable(NetHelper, Variable):
     """
     Available net configuration
     """
@@ -654,7 +656,8 @@ class VariableOsInstallNetConfAvailable(NetHelper,Variable):
                     pass
         return sorted(map(itemgetter(0,2),mapNetConf[-1:]),key=itemgetter(1))
 
-class VariableOsInstallNetConf(NetHelper,Variable):
+
+class VariableOsInstallNetConf(NetHelper, Variable):
     """
     Net setup (networkmanager or openrc)
     """
@@ -676,7 +679,7 @@ class VariableOsInstallNetConf(NetHelper,Variable):
         else:
             nm = ""
         for val,comment in self.Get('os_install_net_conf_available'):
-            if nm == val and not (self.Get('os_root_dev') == '/dev/nfs' and \
+            if nm == val and not (self.Get('os_root_dev') == '/dev/nfs' and
                 self.Get('os_install_root_type') == "livecd"):
                 return nm
         else:
@@ -685,7 +688,8 @@ class VariableOsInstallNetConf(NetHelper,Variable):
     def choice(self):
         return self.Get('os_install_net_conf_available')
 
-class VariableOsInstallNetDnsSearch(NetHelper,Variable):
+
+class VariableOsInstallNetDnsSearch(NetHelper, Variable):
     """
     Dns search
     """
@@ -753,7 +757,8 @@ class VariableOsInstallNetDns(VariableOsInstallNetDnsSearch):
                               if self.isDNSByDHCP()
                               else _("Not used"))
 
-class VariableOsInstallNetSettings(NetHelper,Variable):
+
+class VariableOsInstallNetSettings(NetHelper, Variable):
     """
     Net service configured
     """
