@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 # Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
 #
@@ -18,15 +18,14 @@ import os
 import sys
 import re
 from os import path
-from calculate.lib.datavars import Variable,VariableError,ReadonlyVariable, \
-                                   TableVariable,PasswordError, \
-                                   ReadonlyTableVariable,FieldValue, \
-    DataVarsError
+from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
+                                    TableVariable, PasswordError,
+                                    DataVarsError, VariableInterface)
 from calculate.install.fs_manager import FileSystemManager
-from calculate.lib.utils.files import (readFile,getProgPath,process,
-    readLinesFile)
-from calculate.lib.utils.common import getPasswdUsers,getUserGroups,getGroups
-from calculate.lib.utils.common import getValueFromConfig,getValueFromCmdLine
+from calculate.lib.utils.files import (readFile, getProgPath, process,
+                                       readLinesFile)
+from calculate.lib.utils.common import getPasswdUsers, getUserGroups, getGroups
+from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
@@ -34,11 +33,12 @@ from crypt import crypt
 from calculate.lib.encrypt import encrypt
 import calculate.lib.cl_template as cl_template
 
-from calculate.lib.cl_lang import setLocalTranslate
+from calculate.lib.cl_lang import setLocalTranslate, _
 
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
-class UserHelper:
+
+class UserHelper(VariableInterface):
     """
     Locale variables not using for flash installation
     """
@@ -84,9 +84,9 @@ class VariableOsFormatUse(ReadonlyVariable):
     """
     type = "list"
     # (on or off) autoupdate config from install program
-    cl_autoupdate_set = {'value': "off",
-                'type': "bool",
-                'value': "off"}
+    cl_autoupdate_set = {
+        'type': "bool",
+        'value': "off"}
 
     def checkFunc(self,fs):
         if "format" in FileSystemManager.supportFS[fs] and \
@@ -415,26 +415,13 @@ class VariableClInstallDevFrom(Variable):
             return ""
 
     def get(self):
-        if (self.Get('cl_autopartition_set') == 'on' and 
-            "root" in self.Get('cl_autopartition_scheme')):
+        if (self.Get('cl_autopartition_set') == 'on' and
+                    "root" in self.Get('cl_autopartition_scheme')):
             return self.Select('cl_autopartition_disk_dev',
-                    where='cl_autopartition_disk_scheme',eq='root',limit=1)
+                               where='cl_autopartition_disk_scheme', eq='root',
+                               limit=1)
         return ""
 
-class VariableClInstallAutoupdateSet(Variable):
-    """
-    Autoupdate for install or configure system
-    """
-    def get_cl_install_autoupdate_set(self):
-        """Get autoupdate default value"""
-        if self.Get('ac_install_system') == "up":
-            if self.Get('os_install_linux_system') == 'desktop':
-                return "on"
-            else:
-                return "off"
-        else:
-            return self.Get('cl_autoupdate_set')
-
 class VariableOsNvidiaMask(ReadonlyVariable):
     """
     Get nvidia card mask versions
@@ -445,7 +432,6 @@ class VariableOsNvidiaMask(ReadonlyVariable):
             if image:
                 image = image.convertToDirectory()
                 chrootPath = image.getDirectory()
-                chrootPath = image.getDirectory()
             else:
                 chrootPath = self.Get("cl_chroot_path")
             nvidiaeclass = path.join(chrootPath,
@@ -648,7 +634,7 @@ class VariableOsInstallUefiSet(Variable):
             if not 'gpt' in self.Get('os_device_table'):
                 raise VariableError(
                     _("GPT is needed for using the UEFI bootloader"))
-            if not (self.Get('os_install_disk_efi') or \
+            if not (self.Get('os_install_disk_efi') or
                 "/boot/efi" in self.Get('os_location_dest')):
                 raise VariableError(
                     _("A EF00 partition is needed for using "
@@ -718,7 +704,7 @@ class VariableOsInstallGrubTerminal(Variable):
             return _("Grub configuration unavailable for Flash install")
         return ""
 
-class PackageCheckHelper(ReadonlyVariable):
+class PackageCheckVariable(ReadonlyVariable):
     """
     Конструктор для переменных проверки установлен ли пакет
     """
@@ -746,14 +732,15 @@ class PackageCheckHelper(ReadonlyVariable):
         return "off"
 
 
-class VariableOsInstallAlsaSet(PackageCheckHelper):
+class VariableOsInstallAlsaSet(PackageCheckVariable):
     """
     Установлен ли media-sound/alsa-utils
     """
     image = True
     package = "media-sound/alsa-utils"
 
-class VariableOsInstallX11ServerSet(PackageCheckHelper):
+
+class VariableOsInstallX11ServerSet(PackageCheckVariable):
     """
     Установлен ли x11-base/xorg-server
     """
@@ -761,7 +748,7 @@ class VariableOsInstallX11ServerSet(PackageCheckHelper):
     package = "x11-base/xorg-server"
 
 
-class FlashUncompatible:
+class FlashUncompatible(VariableInterface):
     def uncompatible(self):
         """
         Update setting up unavailable for flash installation
@@ -795,6 +782,8 @@ try:
             return self.Get('update.cl_update_other_set')
 
 except ImportError:
+    update = None
+
     class VariableClInstallAutocheckSet(FlashUncompatible, Variable):
         value = "off"
 
